<?php
/**
Plugin Name: Integration for Gravity Forms and Engaging Networks
Plugin URI: https://cornershopcreative.com/product/gravity-forms-add-ons/
Description: Integrates Gravity Forms with the Engaging Networks CRM, allowing form submissions to automatically create/update supporters and pages
Version: 2.2.7
Author: Cornershop Creative
Author URI: https://cornershopcreative.com
Text Domain: gfen
 */

if ( ! function_exists( 'get_plugin_data' ) ) {
	require_once ABSPATH . 'wp-admin/includes/plugin.php';
}

$gravity_forms_engaging_networks = get_plugin_data( __FILE__, true );
define( 'GF_EN_VERSION', $gravity_forms_engaging_networks['Version'] );
unset( $gravity_forms_engaging_networks );

add_action( 'gform_loaded', array( 'GF_EN_Bootstrap', 'load' ), 5 );
add_action( 'admin_notices', array( 'GF_EN_Bootstrap', 'maybe_show_cipher_warning' ), 11 );

/**
 * Tells GravityForms to load up the Add-On
 */
class GF_EN_Bootstrap {

	/**
	 * Load our functionality if GF can handle it.
	 */
	public static function load() {

		if ( ! method_exists( 'GFForms', 'include_feed_addon_framework' ) ) {
			return;
		}

		require_once 'class-gfen.php';

		GFAddOn::register( 'GFEN' );
	}

	/**
	 * Check whether EN's preferred ciphers are available. If not, display a warning message.
	 */
	public static function maybe_show_cipher_warning() {

		// Bail if this isn't a Gravity Forms-related screen.
		if ( ! class_exists( 'GFForms' ) || ! \GFForms::is_gravity_page() ) {
			return;
		}

		// Bail if the current user doesn't have permission to manage GF settings.
		if ( ! class_exists( 'GFCommon' ) || ! GFCommon::current_user_can_any( GFCommon::all_caps() ) ) {
			return;
		}

		// List from the bottom of EN's info page, as of 8/16/23:
		// https://www.engagingnetworks.support/knowledge-base/important-changes-to-external-integrations-with-engaging-networks/
		$acceptable_ciphers = [
			'aes-128-gcm',
			'aes-256-gcm',
			'chacha20-poly1305',
			'ecdhe-rsa-aes-128-gcm',
			'ecdhe-rsa-aes-256-gcm',
			'ecdhe-rsa-chacha20-poly1305',
		];
		$available_acceptable_ciphers = array_intersect( $acceptable_ciphers, openssl_get_cipher_methods() );
		if ( count( $available_acceptable_ciphers ) < 1 ) {
			?>
			<div class="notice notice-warning gf-notice">
				<p><?php printf(
					// translators: %1$s: opening strong tag, %2$s: closing strong tag, %3$s: opening a tag for knowledge base article, %4$s: closing a tag
					esc_html__( '%1$sWarning: the integration for Gravity Forms and Engaging Networks may not function properly on this web server!%2$s Your server does not support any of the TLS ciphers required by Engaging Networks. Please update to a recent version of PHP, with libcurl compiled against a recent version of OpenSSL. See Engaging Networks\' %3$sknowledge base article on ciphers%4$s for more information.', 'gfen' ),
					'<strong>',
					'</strong>',
					'<a href="https://www.engagingnetworks.support/knowledge-base/important-changes-to-external-integrations-with-engaging-networks/" target="_blank" rel="noopener noreferrer">',
					'</a>'
				); ?></p>
			</div>
			<?php
		}
	}
}

/**
 * Get an instance of our object. Not sure this is necessary?
 */
function gf_en() {
	return GFEN::get_instance();
}
